<?php

namespace Drupal\taxonomy_delete\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class TaxonomyDeleteUIForm.
 *
 * @package Drupal\taxonomy_delete\Form
 */
class TaxonomyDeleteUIForm extends FormBase {

  /**
   * Returns the entity_type.manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a TaxonomyDeleteUIForm form.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Provides an interface for entity type managers.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'taxonomy_delete_ui_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $vocabularies = [];
    foreach ($this->entityTypeManager->getStorage('taxonomy_vocabulary')->loadMultiple() as $vocabulary) {
      $vocabularies[$vocabulary->id()] = $vocabulary->label();
    }

    $form['vocabularies'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Vocabularies'),
      '#options' => $vocabularies,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete Terms'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $selected_vocabulary = array_filter($form_state->getValue('vocabularies'));
    foreach ($selected_vocabulary as $vid) {
      // Batch process the vocabulary to delete the terms in it.
      $batch = [
        'operations' => [
          [
            '\Drupal\taxonomy_delete\TaxonomyDeleteBatch::processVocabulary',
            [$vid],
          ],
        ],
        'finished' => '\Drupal\taxonomy_delete\TaxonomyDeleteBatch::finishProcess',
      ];
      batch_set($batch);
    }
  }

}
